Installation
============

.. contents::
    :local:
    :depth: 1


NumpyBrain is designed to run on across-platforms, including Windows,
GNU/Linux and OSX. It only relies on Python (NumPy and Numba) libraries.

Installation with Anaconda
--------------------------

You can install NumpyBrain from the ``anaconda cloud``. To do so, use::

    conda install -c oujago npbrain

Other useful packages are also recommended, such as matplotlib_ (for visualization),
jupyter_ (a web-based interactive Python development environment).

Installation with pip
---------------------

If you decide not to use ``conda``, you can install NumpyBrain from the Python
package index: https://pypi.python.org/pypi/

To do so, use::

    pip install npbrain

That's all.


.. _matplotlib: http://matplotlib.org/
.. _jupyter: http://jupyter.org/

